# Djask

<div align="center">

<img src="https://raw.githubusercontent.com/z-t-y/Djask/main/icon/djask.svg" width="200" alt="Djask">

![Test Status](https://github.com/z-t-y/Djask/workflows/Test/badge.svg)
![Lint Status](https://github.com/z-t-y/Djask/workflows/Lint/badge.svg)
![Codecov](https://img.shields.io/codecov/c/gh/z-t-y/Djask)
[![Discord](https://img.shields.io/discord/932075032409149570?color=purple&label=discord&logo=discord&logoColor=white)](https://discord.gg/GtFcKUjmk3)

</div>

Djask is a web framework for python which stands on the top of [Flask](https://flask.palletsproject.com) and will be as powerful as [Django](https://djangoproject.com).

## Features

- Web API Support
- Integrated Admin Interface
- Automatic OpenAPI spec generation

More features to be done...

## Documentation

[Djask Documentation](https://djask.readthedocs.io)

[Documentation Progress](https://github.com/z-t-y/Djask/issues/1)

You can have these documentations for more information:

- [APIFlask](https://apiflask.com)
- [Flask](https://flask.palletsprojects.com)
- [SQLAlchemy](https://www.sqlalchemy.org)
- [Flask-SQLAlchemy](https://flask-sqlalchemy.palletsprojects.com)
